@@ -234,15 +234,14 @@ static int edit_envelope (ENVELOPE *en)
   }
   else
   {
-    char *p;
+    const char *p;
 
     buf[0] = 0;
     for (; uh; uh = uh->next)
     {
       if (ascii_strncasecmp ("subject:", uh->data, 8) == 0)
       {
-	p = uh->data + 8;
-	SKIPWS (p);
+	p = skip_email_wsp(uh->data + 8);
 	strncpy (buf, p, sizeof (buf));
       }
     }
@@ -482,7 +481,7 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int flags, int hmfupto)
       /* If the Reply-To: address is a mailing list, assume that it was
        * put there by the mailing list, and use the From: address
        * 
-       * We also take the from header if our correspondant has a reply-to
+       * We also take the from header if our correspondent has a reply-to
        * header which is identical to the electronic mail address given
        * in his From header.
        * 
@@ -1206,8 +1205,6 @@ ci_send_message (int flags,		/* send mode */
     msg->content->unlink = 1;
     msg->content->use_disp = 0;
     msg->content->disposition = DISPINLINE;
-    if (option (OPTTEXTFLOWED) && msg->content->type == TYPETEXT && !ascii_strcasecmp (msg->content->subtype, "plain"))
-      mutt_set_parameter ("format", "flowed", &msg->content->parameter);
     
     if (!tempfile)
     {
@@ -1273,7 +1270,7 @@ ci_send_message (int flags,		/* send mode */
     /* the from address must be set here regardless of whether or not
      * $use_from is set so that the `~P' (from you) operator in send-hook
      * patterns will work.  if $use_from is unset, the from address is killed
-     * after send-hooks are evaulated */
+     * after send-hooks are evaluated */
 
     if (!msg->env->from)
     {
@@ -1306,6 +1303,12 @@ ci_send_message (int flags,		/* send mode */
      */
     msg->replied = 0;
 
+    if (! (flags & SENDKEY))
+    {
+      if (option (OPTTEXTFLOWED) && msg->content->type == TYPETEXT && !ascii_strcasecmp (msg->content->subtype, "plain"))
+        mutt_set_parameter ("format", "flowed", &msg->content->parameter);
+    }
+
     /* $use_from and/or $from might have changed in a send-hook */
     if (killfrom)
     {
@@ -1341,7 +1344,7 @@ ci_send_message (int flags,		/* send mode */
    * envelope sender.
    */
   mutt_message_hook (NULL, msg, M_SEND2HOOK);
-  
+
   /* wait until now to set the real name portion of our return address so
      that $realname can be set in a send-hook */
   if (msg->env->from && !msg->env->from->personal
@@ -1404,8 +1407,17 @@ ci_send_message (int flags,		/* send mode */
 	  mutt_perror (msg->content->filename);
       }
       
-      if (option (OPTTEXTFLOWED))
-	rfc3676_space_stuff (msg);
+      /* If using format=flowed, perform space stuffing.  Avoid stuffing when
+       * recalling a postponed message where the stuffing was already
+       * performed.  If it has already been performed, the format=flowed
+       * parameter will be present.
+       */
+      if (option (OPTTEXTFLOWED) && msg->content->type == TYPETEXT && !ascii_strcasecmp("plain", msg->content->subtype))
+      {
+	char *p = mutt_get_parameter("format", msg->content->parameter);
+	if (ascii_strcasecmp("flowed", NONULL(p)))
+	  rfc3676_space_stuff (msg);
+      }
 
       mutt_message_hook (NULL, msg, M_SEND2HOOK);
     }
